package com.gic.udesk.service.outer.impl;

import com.alibaba.fastjson.JSON;
import com.gic.api.base.commons.ServiceResponse;
import com.gic.udesk.entity.TabUdeskException;
import com.gic.udesk.entity.TabUdeskTapdRel;
import com.gic.udesk.service.UdeskBaseApiService;
import com.gic.udesk.service.UdeskExceptionService;
import com.gic.udesk.service.UdeskTapdRelService;
import com.gic.udesk.utils.UdeskConstant;
import org.apache.commons.collections.CollectionUtils;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.PostConstruct;
import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

@Service("udeskBaseApiService")
public class UdeskBaseApiServiceImpl implements UdeskBaseApiService {
    private static Logger logger = LogManager.getLogger(UdeskBaseApiServiceImpl.class);

    @Autowired
    private UdeskExceptionService udeskExceptionService;
    @Autowired
    private UdeskTapdRelService udeskTapdRelService;

    @Resource(name = "udeskTapdRelMap")
    private Map<String, String> udeskTapdRelMap;

    @PostConstruct
    public void init() {
        logger.info("初始化udeskTapdRelMap启动。。。。。。。。。。。。。。。");
        List<TabUdeskTapdRel> list = udeskTapdRelService.list(null);
        if (CollectionUtils.isNotEmpty(list)) {
            logger.info("共有" + list.size() + "条数据要处理");
            for (TabUdeskTapdRel tabUdeskTapdRel : list) {
                Integer relType = tabUdeskTapdRel.getRelType();
                if (relType == 1) {
                    // 1 udesk的业务模块与tapd项目的对应
                    udeskTapdRelMap.put(tabUdeskTapdRel.getUdeskIdKey() + ":" + tabUdeskTapdRel.getUdeskIdValue(),
                            tabUdeskTapdRel.getTapdId());
                    continue;
                } else if (relType == 8) {
                    // 8 udesk状态 -> tapd状态
                    udeskTapdRelMap.put(tabUdeskTapdRel.getUdeskName(), tabUdeskTapdRel.getTapdId());
                    continue;
                } else if (relType == 5 || relType == 4 || relType == 7) {
                    // 4 tapd严重程度->udsek 5 tapd状态  -> udesk状态  7 优先级
                    udeskTapdRelMap.put(tabUdeskTapdRel.getTapdId() + UdeskConstant.MAP_UDESK_ID_VALUE_SUFFIX,
                            tabUdeskTapdRel.getUdeskIdValue());
                    udeskTapdRelMap.put(tabUdeskTapdRel.getTapdId() + UdeskConstant.MAP_UDESK_NAME_SUFFIX,
                            tabUdeskTapdRel.getUdeskName());
                    if (relType == 4) {
                        // udesk严重程度字段名：idvalue -> udsek严重程度CN
                        udeskTapdRelMap.put(tabUdeskTapdRel.getUdeskIdKey() + ":" + tabUdeskTapdRel.getUdeskIdValue(),
                                tabUdeskTapdRel.getUdeskName());
                    }
                    continue;
                } else if (relType == 6) {
                    // 6 客服
                    udeskTapdRelMap.put(UdeskConstant.UDESK_DEFAULT_AGENT, tabUdeskTapdRel.getUdeskIdValue());
                    continue;
                }
                udeskTapdRelMap.put(tabUdeskTapdRel.getUdeskIdKey() + ":" + tabUdeskTapdRel.getUdeskIdValue(),
                        tabUdeskTapdRel.getUdeskName());
            }
            logger.info("初始化udeskTapdRelMap完成：" + JSON.toJSONString(udeskTapdRelMap));
        }

    }

    @Override
    public ServiceResponse<Void> saveUdeskException(String exceptionRecord) {
        TabUdeskException exception = new TabUdeskException();
        exception.setExpType(UdeskConstant.UDESK_EXP_TYPE);
        exception.setExceptionRecord(exceptionRecord);
        udeskExceptionService.save(exception);
        return ServiceResponse.success();
    }

    @Override
    public ServiceResponse<Void> saveTapdException(String exceptionRecord) {
        TabUdeskException exception = new TabUdeskException();
        exception.setExpType(UdeskConstant.TAPD_EXP_TYPE);
        exception.setExceptionRecord(exceptionRecord);
        udeskExceptionService.save(exception);
        return ServiceResponse.success();
    }
}
